@@ -58,6 +58,10 @@ schema = atapi.Schema((
 
 Interview_schema = atapi.BaseSchema.copy() + schema.copy()
 
+for schema_key in Interview_schema.keys():
+    if not Interview_schema[schema_key].schemata == 'default':
+        Interview_schema[schema_key].widget.visible={'edit':'invisible',
+                                                     'view':'invisible'}
 
 class JobPerformanceInterview(atapi.BaseContent):
     """
